Environment Runners
===================

Single agent
------------

.. autoclass:: ai_traineree.runners.env_runner.EnvRunner
    :members:
    :undoc-members:

.. autoclass:: ai_traineree.runners.env_runner.MultiSyncEnvRunner
    :members:
    :undoc-members:


Multi agent
-----------

.. autoclass:: ai_traineree.runners.multiagent_env_runner.MultiAgentCycleEnvRunner
    :members:
    :undoc-members:

.. autoclass:: ai_traineree.runners.multiagent_env_runner.MultiAgentEnvRunner
    :members:
    :undoc-members:
